#[non_exhaustive]pub enum ExtensionRegistryError {
AlreadyRegistered(String),
NotRegistered(String),
Downcast(String),
Other(Box<dyn Error + Send + Sync>),
}Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
AlreadyRegistered(String)
The provided context was already registered. Contains the type_name
of the provided context.
NotRegistered(String)
Unable to find a context instance of the requested type. Contains the type_name
of the requested type.
Downcast(String)
Unable to downcast the registered instance to the requested type. Contains the type_name
of the requested type.
Other(Box<dyn Error + Send + Sync>)