Struct AppContext

pub struct AppContext { /* private fields */ }

Implementations

Source

impl AppContext

pub fn downgrade(&self) -> AppContextWeak

Get an AppContextWeak from Self.

pub fn config(&self) -> &AppConfig

Get the app’s AppContext.

pub fn metadata(&self) -> &AppMetadata

Get the app’s AppMetadata

pub fn health_checks(&self) -> Vec<Arc<dyn HealthCheck>>

Returns the HealthChecks that were registered in the HealthCheckRegistry, or an empty Vec if no HealthChecks were registered.

pub fn sea_orm(&self) -> &DatabaseConnection

Get the sea-orm DB connection pool.

pub fn diesel_pg_pool(&self) -> &DieselPgPool

pub fn diesel_mysql_pool(&self) -> &DieselMysqlPool

pub fn diesel_sqlite_pool(&self) -> &DieselSqlitePool

pub fn diesel_pg_pool_async(&self) -> &DieselPgPoolAsync

pub fn diesel_mysql_pool_async(&self) -> &DieselMysqlPoolAsync

pub fn redis_enqueue(&self) -> &RedisEnqueue

Get the Redis connection pool used to enqueue Sidekiq jobs.

pub fn redis_fetch(&self) -> &Option<RedisFetch>

Get the Redis connection pool used to fetch Sidekiq jobs. This shouldn’t be needed by most applications but is provided as a convenience in case it is.

pub fn smtp(&self) -> &SmtpTransport

Get the SMTP client. Used to send emails via the SMTP protocol

pub fn sendgrid(&self) -> &Sender

Get the Sendgrid client. Used to send emails via Sendgrid’s Mail Send API.