pub struct AppContextWeak { /* private fields */ }Expand description
A version of AppContext that holds a Weak pointer to the inner context. Useful for
preventing reference cycles between things that are held in the AppContext and also
need a reference to the AppContext; for example, HealthChecks.
Implementations
Sourceimpl AppContextWeak
impl AppContextWeak
Sourcepub fn upgrade(&self) -> Option<AppContext>
pub fn upgrade(&self) -> Option<AppContext>
Get an AppContext from Self.