MockProvideRef

Struct MockProvideRef 

pub struct MockProvideRef<T> { /* private fields */ }
Trait to allow getting a reference to the T from the implementing type. AppContext implements this for various types it contains. This allows a method to specify the type it requires, then the caller of the method can determine how to provide the type. This is a similar concept to dependency injection (DI) in frameworks like Java Spring, though this is far from a full DI system.

This is useful, for example, to allow mocking the DB connection in tests. Your DB operation method would declare a parameter of type ProvideRef<DataBaseConnection>, then your application code would provide the AppContext to the method, and your tests could provide a mocked ProvideRef instance that returns a mock DB connection. Note that mocking the DB comes with its own set of trade-offs, for example, it may not exactly match the behavior of an actual DB that’s used in production. Consider testing against an actual DB instead of mocking, e.g., by using test containers.

A mocked implementation of the trait is provided if the testing-mocks feature is enabled.

See also:

Implementations

Source

impl<T> MockProvideRef<T>

pub fn checkpoint(&mut self)

Validate that all current expectations for all methods have been satisfied, and discard them.

pub fn new() -> Self

Create a new mock object with no expectations.

This method will not be generated if the real struct already has a new method. However, it will be generated if the struct implements a trait with a new method. The trait’s new method can still be called like <MockX as TraitY>::new

Source

impl<T> MockProvideRef<T>

pub fn expect_provide(&mut self) -> &mut Expectation<T>

Create an Expectation for mocking the provide method