Struct RoadsterAppBuilder

pub struct RoadsterAppBuilder<S, Cli: 'static + Args + RunCommand<RoadsterApp<S, Cli>, S> + Send + Sync = Empty>
where S: Clone + Send + Sync + 'static, AppContext: FromRef<S>,
{ /* private fields */ }
Builder-style API to build/customize a RoadsterApp.

See https://github.com/roadster-rs/roadster/tree/main/examples/app-builder/src/main.rs for an example of how to use the RoadsterAppBuilder.

The Cli type parameter is only required when the using a custom CLI.

Implementations

Source

impl<S, Cli: 'static + Args + RunCommand<RoadsterApp<S, Cli>, S> + Send + Sync> RoadsterAppBuilder<S, Cli>
where S: 'static + Clone + Send + Sync, AppContext: FromRef<S>,

pub fn new() -> Self

pub fn add_async_config_source( self, source: impl AsyncSource + Send + 'static, ) -> Self

Add an async config source (AsyncSource). Useful to load configs/secrets from an external service, e.g., AWS or GCS secrets manager services.

pub fn add_async_config_source_provider( self, source_provider: impl 'static + Send + Sync + Fn(&Environment) -> RoadsterResult<Box<dyn AsyncSource + Send + Sync>>, ) -> Self

Add an async config source (AsyncSource). Useful to load configs/secrets from an external service, e.g., AWS or GCS secrets manager services.

pub fn tracing_initializer( self, tracing_initializer: impl 'static + Send + Sync + Fn(&AppConfig) -> RoadsterResult<()>, ) -> Self

Provide the logic to initialize tracing for the RoadsterApp.

pub fn metadata(self, metadata: AppMetadata) -> Self

Provide the AppMetadata for the RoadsterApp.

pub fn metadata_provider( self, metadata_provider: impl 'static + Send + Sync + Fn(&AppConfig) -> RoadsterResult<AppMetadata>, ) -> Self

Provide the logic to build the AppMetadata for the RoadsterApp.

pub fn sea_orm_conn_options(self, sea_orm_conn_options: ConnectOptions) -> Self

Provide the ConnectOptions for the RoadsterApp.

pub fn sea_orm_conn_options_provider( self, sea_orm_conn_options_provider: impl 'static + Send + Sync + Fn(&AppConfig) -> RoadsterResult<ConnectOptions>, ) -> Self

Provide the logic to build the ConnectOptions for the RoadsterApp.

pub fn diesel_pg_connection_customizer( self, connection_customizer: impl 'static + CustomizeConnection<DieselPgConn, Error>, ) -> Self

pub fn diesel_pg_connection_customizer_provider( self, connection_customizer: impl 'static + Send + Sync + Fn(&AppConfig) -> RoadsterResult<Box<dyn CustomizeConnection<DieselPgConn, Error>>>, ) -> Self

pub fn diesel_mysql_connection_customizer( self, connection_customizer: impl 'static + CustomizeConnection<DieselMysqlConn, Error>, ) -> Self

pub fn diesel_mysql_connection_customizer_provider( self, connection_customizer: impl 'static + Send + Sync + Fn(&AppConfig) -> RoadsterResult<Box<dyn CustomizeConnection<DieselMysqlConn, Error>>>, ) -> Self

pub fn diesel_sqlite_connection_customizer( self, connection_customizer: impl 'static + CustomizeConnection<DieselSqliteConn, Error>, ) -> Self

pub fn diesel_sqlite_connection_customizer_provider( self, connection_customizer: impl 'static + Send + Sync + Fn(&AppConfig) -> RoadsterResult<Box<dyn CustomizeConnection<DieselSqliteConn, Error>>>, ) -> Self

pub fn diesel_pg_async_connection_customizer( self, connection_customizer: impl 'static + CustomizeConnection<DieselPgConnAsync, PoolError>, ) -> Self

pub fn diesel_pg_async_connection_customizer_provider( self, connection_customizer: impl 'static + Send + Sync + Fn(&AppConfig) -> RoadsterResult<Box<dyn CustomizeConnection<DieselPgConnAsync, PoolError>>>, ) -> Self

pub fn diesel_mysql_async_connection_customizer( self, connection_customizer: impl 'static + CustomizeConnection<DieselMysqlConnAsync, PoolError>, ) -> Self

pub fn diesel_mysql_async_connection_customizer_provider( self, connection_customizer: impl 'static + Send + Sync + Fn(&AppConfig) -> RoadsterResult<Box<dyn CustomizeConnection<DieselMysqlConnAsync, PoolError>>>, ) -> Self

pub fn state_provider( self, builder: impl 'static + Send + Sync + Fn(AppContext) -> RoadsterResult<S>, ) -> Self

Provide the logic to build the custom state for the RoadsterApp.

pub fn sea_orm_migrator( self, migrator: impl 'static + Sync + MigratorTrait, ) -> Self

Add the diesel migrator sea_orm_migration::MigratorTrait to run on app start up (if the database.auto-migrate config field is set to true)

Note: SeaORM migrations expect all of the applied migrations to be available to the provided migrator, so only a single SeaORM migrator is allowed.

pub fn diesel_migrator<C>( self, migrator: impl 'static + Send + Sync + MigrationSource<C::Backend>, ) -> Self
where C: 'static + Connection + Send + MigrationHarness<C::Backend>,

Add the diesel migrator diesel::migration::MigrationSource to run on app start up (if the database.auto-migrate config field is set to true)

Note: Diesel migrations expect all of the applied migrations to be available to the provided migrator, so only a single Diesel migrator is allowed.

pub fn add_migrator(self, migrator: impl Migrator<S> + 'static) -> Self

Add a Migrator to run on app start up (if the database.auto-migrate config field is set to true).

Note: SeaORM and Diesel migrations expect all of the applied migrations to be available to the provided migrator, so multiple SeaORM or Diesel migrators should not be provided via this method.

pub fn add_migrator_provider( self, migrator_provider: impl 'static + Send + Sync + Fn(&S) -> RoadsterResult<Box<dyn Migrator<S>>>, ) -> Self

Add a [MigratorProvider] that provides a Migrator to run on app start up (if the database.auto-migrate config field is set to true).

This is useful compared to Self::add_migrator if the Migrator implementation needs access to the app state for any reason.

Note: SeaORM and Diesel migrations expect all of the applied migrations to be available to the provided migrator, so multiple SeaORM or Diesel migrators should not be provided via this method.

pub fn add_lifecycle_handler( self, lifecycle_handler: impl 'static + AppLifecycleHandler<RoadsterApp<S, Cli>, S>, ) -> Self

Add a AppLifecycleHandler for the RoadsterApp.

This method can be called multiple times to register multiple handlers.

pub fn add_lifecycle_handler_provider( self, lifecycle_handler_provider: impl 'static + Send + Sync + Fn(&mut LifecycleHandlerRegistry<RoadsterApp<S, Cli>, S>, &S) -> RoadsterResult<()>, ) -> Self

Provide the logic to register AppLifecycleHandlers for the RoadsterApp.

This method can be called multiple times to register multiple handlers in separate callbacks.

pub fn add_health_check(self, health_check: impl 'static + HealthCheck) -> Self

Add a HealthCheck for the RoadsterApp.

This method can be called multiple times to register multiple health checks.

pub fn add_health_check_provider( self, health_check_provider: impl 'static + Send + Sync + Fn(&mut HealthCheckRegistry, &S) -> RoadsterResult<()>, ) -> Self

Provide the logic to register HealthChecks for the RoadsterApp.

This method can be called multiple times to register multiple health checks in separate callbacks.

pub fn add_service( self, service: impl 'static + AppService<RoadsterApp<S, Cli>, S>, ) -> Self

Add a AppService for the RoadsterApp.

This method can be called multiple times to register multiple services.

pub fn add_service_provider( self, service_provider: impl 'static + Send + Sync + for<'a> Fn(&'a mut ServiceRegistry<RoadsterApp<S, Cli>, S>, &'a S) -> Pin<Box<dyn Send + Future<Output = RoadsterResult<()>> + 'a>>, ) -> Self

Provide the logic to register AppServices for the RoadsterApp.

This method can be called multiple times to register multiple services in separate callbacks.

pub fn graceful_shutdown_signal_provider( self, graceful_shutdown_signal_provider: impl 'static + Send + Sync + Fn(&S) -> Pin<Box<dyn Send + Future<Output = ()>>>, ) -> Self

Provide a custom signal to listen for in order to shutdown the RoadsterApp.

pub fn build(self) -> RoadsterApp<S, Cli>

Build the RoadsterApp from this RoadsterAppBuilder.