#[non_exhaustive]pub struct Database {
pub uri: Url,
pub auto_migrate: bool,
pub temporary_test_db: bool,
pub temporary_test_db_clean_up: bool,
pub pool_config: DbPoolConfig,
pub statement_log_config: StatementLogConfig,
pub test_container: Option<TestContainer>,
}Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.uri: UrlThis can be overridden with an environment variable, e.g. ROADSTER__DATABASE__URI=postgres://example:example@example:1234/example_app
auto_migrate: boolWhether to automatically apply migrations during the app’s start up. Migrations can also
be manually performed via the roadster migration [COMMAND] CLI command.
temporary_test_db: boolCreate a temporary database in the same DB host from the uri field.
temporary_test_db_clean_up: boolAutomatically clean up (drop) the temporary test DB that was created by setting
temporary_test_db to true. Note that the test DB will only be cleaned up if the closure
passed to crate::app::run_test or crate::app::run_test_with_result doesn’t panic.
pool_config: DbPoolConfigstatement_log_config: StatementLogConfigtest_container: Option<TestContainer>Options for creating a Test Container instance for the DB. If enabled, the Database#uri
field will be overridden to be the URI for the Test Container instance that’s created when
building the app’s crate::app::context::AppContext.