Tracing

Struct Tracing 

#[non_exhaustive]
pub struct Tracing { pub level: String, pub format: Format, pub service_name: Option<String>, pub trace_propagation: bool, pub trace_sampling_ratio: Option<f64>, pub metrics_export_interval: Option<Duration>, pub trace_filters: Vec<String>, pub otlp: Option<Otlp>, }

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
level: Stringformat: Format

The format to use when printing traces to logs.

service_name: Option<String>

The name of the service to use for the OpenTelemetry service.name field. If not provided, will use the App::name config value, translated to snake_case.

trace_propagation: bool

Propagate traces across service boundaries. Mostly useful in microservice architectures.

trace_sampling_ratio: Option<f64>

Head sampling ratio. Many applications will not need this and instead may benefit more from tail sampling, which allows different sampling policies depending on the state of the trace at the end of the trace, e.g., sampling 100% of error traces and 10% of success traces. Tail sampling is generally not configured in the application and instead is configured in the OTEL collector or your specific observability vendor.

If an application emits a sufficiently massive number of traces, head sampling may be needed in addition to tail sampling.

If provided, a Sampler::TraceIdRatioBased will be added to the OTLP trace layer.

metrics_export_interval: Option<Duration>

The interval (in milliseconds) at which OTEL metrics are exported.

trace_filters: Vec<String>

Filter directives to provide to the tracing-subscriber EnvFilter.

Useful for filtering out noisy debug/trace logs from dev environments, or setting a different log level for a specific crate in all environments

otlp: Option<Otlp>

Configuration for OTLP exporters.