#[non_exhaustive]pub struct JwtCsrf<C = Claims> {
pub token: Jwt<C>,
pub csrf_status: CsrfStatus,
}Expand description
Similar to Jwt, but allows extracting the JWT from the request cookies (if the
auth.jwt.cookie-name config is set) in addition to the request header.
This is useful for use in web-apps because the JWT can be set as a cookie and be automatically sent along with every request instead of needing to add the header to every request (which would preclude the web-app from supporting clients without javascript enabled). However, THIS MAY MAKE THE CONSUMING APPLICATION VULNERABLE TO CSRF ATTACKS. If this struct is used, the consuming application should implement a CSRF protection mechanism. See the following for more information and recommendations:
- https://owasp.org/www-community/attacks/csrf
- https://cheatsheetseries.owasp.org/cheatsheets/Cross-Site_Request_Forgery_Prevention_Cheat_Sheet.html
If the functionality to extract from a cookie is not required, it’s recommended to use
the normal Jwt directly.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.token: Jwt<C>csrf_status: CsrfStatusImplementations