Module service

Module service 

Structs

FunctionService
A generic Service to allow creating a service from an async function.
FunctionServiceBuilder
Use builder syntax to set the inputs and finish with build().