pub struct HttpService { /* private fields */ }Implementations
Sourceimpl HttpService
impl HttpService
Sourcepub fn builder<S>(path_root: Option<&str>, state: &S) -> HttpServiceBuilder<S>
pub fn builder<S>(path_root: Option<&str>, state: &S) -> HttpServiceBuilder<S>
Create a new HttpServiceBuilder.
pub fn router(&self) -> &Router
Sourcepub fn list_routes(&self) -> Vec<(&str, &str)>
pub fn list_routes(&self) -> Vec<(&str, &str)>
List the available HTTP API routes.
Note that in order for a route to show up where, it needs to be registered with an
aide::axum::ApiRouter and provided when building the HttpService.
Sourcepub fn print_open_api_schema(&self, options: &OpenApiArgs) -> RoadsterResult<()>
pub fn print_open_api_schema(&self, options: &OpenApiArgs) -> RoadsterResult<()>
Generate an OpenAPI schema for the HTTP API and either print to stdout or to the path
provided in OpenApiArgs.
Sourcepub fn open_api_schema(&self, options: &OpenApiArgs) -> RoadsterResult<String>
pub fn open_api_schema(&self, options: &OpenApiArgs) -> RoadsterResult<String>
Generate an OpenAPI schema for the HTTP API and either return it as a JSON string.
Note: This method ignores the output field of OpenApiArgs.