pub struct ServiceRegistry<S>{ /* private fields */ }Expand description
Registry for Services that will be run in the app.
Implementations
Sourceimpl<S> ServiceRegistry<S>
impl<S> ServiceRegistry<S>
Sourcepub fn register_service<Srvc>(&mut self, service: Srvc) -> RoadsterResult<()>where
Srvc: Service<S> + 'static,
pub fn register_service<Srvc>(&mut self, service: Srvc) -> RoadsterResult<()>where
Srvc: Service<S> + 'static,
Register a new service. If the service is not enabled (e.g., Service::enabled is false),
the service will not be registered.
Sourcepub async fn register_builder<Srvc, B>(
&mut self,
builder: B,
) -> RoadsterResult<()>where
Srvc: Service<S> + 'static,
B: ServiceBuilder<S, Srvc>,
pub async fn register_builder<Srvc, B>(
&mut self,
builder: B,
) -> RoadsterResult<()>where
Srvc: Service<S> + 'static,
B: ServiceBuilder<S, Srvc>,
Build and register a new service. If the service is not enabled (e.g.,
Service::enabled is false), the service will not be built or registered.
Sourcepub fn get<Srvc>(&self) -> RoadsterResult<&Srvc>where
Srvc: Service<S> + 'static,
pub fn get<Srvc>(&self) -> RoadsterResult<&Srvc>where
Srvc: Service<S> + 'static,
Get a reference to a previously registered Service of the specified type.
This is useful to call a method that only exists on a concrete Service
implementor after the app was prepared.
For example, to get the OpenAPI schema for an app,
setup and register the crate::service::http::service::HttpService, get the service
from the registry with this method (ServiceRegistry::get), and call
crate::service::http::service::HttpService::print_open_api_schema to get the schema.
Examples
type App = RoadsterApp<AppContext>;
let app: App = RoadsterApp::builder()
.state_provider(|state| Ok(state))
.add_service_provider(|registry, state| Box::pin(async {
registry.register_builder(
HttpService::builder(Some("/api"), state)
).await?;
Ok(())
}))
.build();
// Prepare the app. This runs all initialization logic for the app but does not actually
// start the app.
let prepared = prepare(
app,
PrepareOptions::builder()
.env(Environment::Development)
.build()
).await.unwrap();
// Get the `HttpService` from the `ServiceRegistry`
let http_service = prepared.service_registry.get::<HttpService>().unwrap();
// Get the OpenAPI schema from the `HttpService`
http_service.open_api_schema(&OpenApiArgs::builder().build()).unwrap();Auto Trait Implementations
impl<S> !RefUnwindSafe for ServiceRegistry<S>
impl<S> !UnwindSafe for ServiceRegistry<S>
impl<S> Freeze for ServiceRegistry<S>
impl<S> Send for ServiceRegistry<S>
impl<S> Sync for ServiceRegistry<S>
impl<S> Unpin for ServiceRegistry<S>
impl<S> UnsafeUnpin for ServiceRegistry<S>