Module snapshot

Module snapshot 

Utilities for modifying insta snapshot Settings.

Structs

TestCase
Container for common insta snapshot Settings after they have been applied per the TestCaseConfig.
TestCaseConfig
Configure which settings to apply on the snapshot Settings.
TestCaseConfigBuilder
Use builder syntax to set the inputs and finish with build_internal().

Functions

snapshot_redact_bearer_tokens
Redact instances of bearer tokens in snapshots. Applies a filter on the Settings to replace sub-strings matching [BEARER_TOKEN_REGEX] with Sensitive.
snapshot_redact_mysql_uri
Redact instances of Mysql URIs in snapshots. Applies a filter on the Settings to replace sub-strings matching [MYSQL_URI_REGEX] with mysql://[Sensitive].
snapshot_redact_postgres_uri
Redact instances of Postgres URIs in snapshots. Applies a filter on the Settings to replace sub-strings matching [POSTGRES_URI_REGEX] with postgres://[Sensitive].
snapshot_redact_redis_uri
Redact instances of Redis URIs in snapshots. Applies a filter on the Settings to replace sub-strings matching [REDIS_URI_REGEX] with redis://[Sensitive].
snapshot_redact_smtp_uri
Redact instances of Smtp URIs in snapshots. Applies a filter on the Settings to replace sub-strings matching [SMTP_URI_REGEX] with smtp://[Sensitive].
snapshot_redact_timestamp
Redact instances of timestamps in snapshots. Applies a filter on the Settings to replace sub-strings matching [TIMESTAMP_REGEX] with [timestamp].
snapshot_redact_uuid
Redact instances of UUIDs in snapshots. Applies a filter on the Settings to replace sub-strings matching UUID_REGEX with [uuid].
snapshot_set_suffix
Set the snapshot suffix on the Settings.