WorkerConfigBuilder

Struct WorkerConfigBuilder 

pub struct WorkerConfigBuilder<S: State = Empty> { /* private fields */ }
Use builder syntax to set the inputs and finish with build().

Implementations

Source

impl<S: State> WorkerConfigBuilder<S>

pub fn build(self) -> WorkerConfig
where S: IsComplete,

Finish building and return the requested object

pub fn timeout(self, value: bool) -> WorkerConfigBuilder<SetTimeout<S>>
where S::Timeout: IsUnset,

Optional (Some / Option setters). True if Roadster should enforce a timeout on the app’s workers. The default duration of the timeout can be configured with the max-duration option.

pub fn maybe_timeout( self, value: Option<bool>, ) -> WorkerConfigBuilder<SetTimeout<S>>
where S::Timeout: IsUnset,

Optional (Some / Option setters). True if Roadster should enforce a timeout on the app’s workers. The default duration of the timeout can be configured with the max-duration option.

pub fn max_duration( self, value: Duration, ) -> WorkerConfigBuilder<SetMaxDuration<S>>
where S::MaxDuration: IsUnset,

Optional (Some / Option setters). The maximum duration workers should run for. The timeout is only enforced if timeout is true.

pub fn maybe_max_duration( self, value: Option<Duration>, ) -> WorkerConfigBuilder<SetMaxDuration<S>>
where S::MaxDuration: IsUnset,

Optional (Some / Option setters). The maximum duration workers should run for. The timeout is only enforced if timeout is true.

pub fn retry_config( self, value: RetryConfig, ) -> WorkerConfigBuilder<SetRetryConfig<S>>
where S::RetryConfig: IsUnset,

Optional (Some / Option setters). The worker retry configuration. If no configuration is provided, either in the app’s config or for the crate::worker::Worker, the worker will not retry.

pub fn maybe_retry_config( self, value: Option<RetryConfig>, ) -> WorkerConfigBuilder<SetRetryConfig<S>>
where S::RetryConfig: IsUnset,

Optional (Some / Option setters). The worker retry configuration. If no configuration is provided, either in the app’s config or for the crate::worker::Worker, the worker will not retry.

pub fn sidekiq( self, value: SidekiqWorkerConfig, ) -> WorkerConfigBuilder<SetSidekiq<S>>
where S::Sidekiq: IsUnset,

Optional (Some / Option setters).

pub fn maybe_sidekiq( self, value: Option<SidekiqWorkerConfig>, ) -> WorkerConfigBuilder<SetSidekiq<S>>
where S::Sidekiq: IsUnset,

Optional (Some / Option setters).

pub fn pg(self, value: PgWorkerConfig) -> WorkerConfigBuilder<SetPg<S>>
where S::Pg: IsUnset,

Optional (Some / Option setters).

pub fn maybe_pg( self, value: Option<PgWorkerConfig>, ) -> WorkerConfigBuilder<SetPg<S>>
where S::Pg: IsUnset,

Optional (Some / Option setters).

pub fn custom(self, value: CustomConfig) -> WorkerConfigBuilder<SetCustom<S>>
where S::Custom: IsUnset,

Optional (Some / Option setters). Default: <CustomConfig as Default>::default().

pub fn maybe_custom( self, value: Option<CustomConfig>, ) -> WorkerConfigBuilder<SetCustom<S>>
where S::Custom: IsUnset,

Optional (Some / Option setters). Default: <CustomConfig as Default>::default().