pub struct AppContext { /* private fields */ }Implementations
Sourceimpl AppContext
impl AppContext
Sourcepub fn downgrade(&self) -> AppContextWeak
pub fn downgrade(&self) -> AppContextWeak
Get an AppContextWeak from Self.
Sourcepub fn config(&self) -> &AppConfig
pub fn config(&self) -> &AppConfig
Get the app’s AppContext.
Sourcepub fn metadata(&self) -> &AppMetadata
pub fn metadata(&self) -> &AppMetadata
Get the app’s AppMetadata
Sourcepub fn health_checks(&self) -> Vec<Arc<dyn HealthCheck>>
pub fn health_checks(&self) -> Vec<Arc<dyn HealthCheck>>
Returns the HealthChecks that were registered in the HealthCheckRegistry, or
an empty Vec if no HealthChecks were registered.
Sourcepub fn sea_orm(&self) -> &DatabaseConnection
pub fn sea_orm(&self) -> &DatabaseConnection
Get the sea-orm DB connection pool.
pub fn diesel_pg_pool(&self) -> &DieselPgPool
pub fn diesel_mysql_pool(&self) -> &DieselMysqlPool
pub fn diesel_sqlite_pool(&self) -> &DieselSqlitePool
pub fn diesel_pg_pool_async(&self) -> &DieselPgPoolAsync
pub fn diesel_mysql_pool_async(&self) -> &DieselMysqlPoolAsync
Sourcepub fn redis_enqueue(&self) -> &RedisEnqueue
pub fn redis_enqueue(&self) -> &RedisEnqueue
Get the Redis connection pool used to enqueue Sidekiq jobs.
Sourcepub fn redis_fetch(&self) -> &Option<RedisFetch>
pub fn redis_fetch(&self) -> &Option<RedisFetch>
Get the Redis connection pool used to fetch Sidekiq jobs. This shouldn’t be needed by most applications but is provided as a convenience in case it is.
Sourcepub fn smtp(&self) -> &SmtpTransport
pub fn smtp(&self) -> &SmtpTransport
Get the SMTP client. Used to send emails via the SMTP protocol