Struct Database

#[non_exhaustive]
pub struct Database {
Show 14 fields pub uri: Url, pub auto_migrate: bool, pub connect_timeout: Duration, pub connect_lazy: bool, pub acquire_timeout: Duration, pub idle_timeout: Option<Duration>, pub max_lifetime: Option<Duration>, pub min_connections: u32, pub max_connections: u32, pub test_on_checkout: bool, pub retry_connection: bool, pub temporary_test_db: bool, pub temporary_test_db_clean_up: bool, pub test_container: Option<TestContainer>,
}

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
uri: Url

This can be overridden with an environment variable, e.g. ROADSTER__DATABASE__URI=postgres://example:example@example:1234/example_app

auto_migrate: bool

Whether to automatically apply migrations during the app’s start up. Migrations can also be manually performed via the roadster migration [COMMAND] CLI command.

connect_timeout: Durationconnect_lazy: bool

Whether to attempt to connect to the DB immediately when the DB connection pool is created. If true will wait to connect to the DB until the first DB query is attempted.

acquire_timeout: Durationidle_timeout: Option<Duration>max_lifetime: Option<Duration>min_connections: u32max_connections: u32test_on_checkout: boolretry_connection: booltemporary_test_db: bool

Create a temporary database in the same DB host from the uri field.

temporary_test_db_clean_up: bool

Automatically clean up (drop) the temporary test DB that was created by setting temporary_test_db to true.

test_container: Option<TestContainer>

Options for creating a Test Container instance for the DB. If enabled, the Database#uri field will be overridden to be the URI for the Test Container instance that’s created when building the app’s crate::app::context::AppContext.