Modules
Traits
- Service
- Trait to represent a service (e.g., a persistent task) to run in the app.
- Service
AsAny - Allows getting an
&dyn Anyreference to theService. This is to enable getting a concrete reference to a specificServiceimplementation from theregistry::ServiceRegistry(which works via a downcast) in order to call methods that are specific to a certain implementation. Seeregistry::ServiceRegistry::getfor more details and examples. - Service
Builder - Trait used to build a
Service. It’s not a requirement that services implement this trait; it is provided as a convenience. A builder can be provided to theServiceRegistryinstead of aService, in which case theServiceRegistrywill only build and register the service ifService::enabledistrue.